ComplexEOFRotator
=================

.. currentmodule:: xeofs.single

.. autoclass:: ComplexEOFRotator
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ComplexEOFRotator.__init__
      ~ComplexEOFRotator.components
      ~ComplexEOFRotator.components_amplitude
      ~ComplexEOFRotator.components_phase
      ~ComplexEOFRotator.compute
      ~ComplexEOFRotator.deserialize
      ~ComplexEOFRotator.explained_variance
      ~ComplexEOFRotator.explained_variance_ratio
      ~ComplexEOFRotator.fit
      ~ComplexEOFRotator.fit_transform
      ~ComplexEOFRotator.get_params
      ~ComplexEOFRotator.get_serialization_attrs
      ~ComplexEOFRotator.inverse_transform
      ~ComplexEOFRotator.load
      ~ComplexEOFRotator.save
      ~ComplexEOFRotator.scores
      ~ComplexEOFRotator.scores_amplitude
      ~ComplexEOFRotator.scores_phase
      ~ComplexEOFRotator.serialize
      ~ComplexEOFRotator.singular_values
      ~ComplexEOFRotator.transform
   
   

   
   
   